@@ -30,29 +30,17 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die( 'Restricted access' );
 
-$dateTimeFormat = '%d %b, %Y %I:%M %p';
-$tz = null;
-
-if (version_compare(JVERSION, '1.6', 'ge'))
-{
-	$dateTimeFormat = 'd M, Y h:i A';
-	$tz = false;
-}
-
-JToolBarHelper::title( JText::_( 'MEMBERS' ).': <small><small>[ Manage Points ]</small></small>', 'user.png' );
+JToolBarHelper::title( JText::_( 'MEMBERS' ).': Manage Points', 'user.png' );
 
 ?>
-<div role="navigation" class="sub-navigation">
-	<ul id="subsubmenu">
-		<li><a href="index.php?option=<?php echo $this->option; ?>&amp;controller=<?php echo $this->controller; ?>">Summary</a></li> 
-		<li><a href="index.php?option=<?php echo $this->option; ?>&amp;controller=<?php echo $this->controller; ?>&amp;task=edit" class="active">Look up User Balance</a></li>
-		<li><a href="index.php?option=<?php echo $this->option; ?>&amp;controller=<?php echo $this->controller; ?>&amp;task=config">Configuration</a></li> 
-		<li><a href="index.php?option=<?php echo $this->option; ?>&amp;controller=<?php echo $this->controller; ?>&amp;task=batch">Batch Transaction</a></li>
-	</ul>
-</div>
+
+<?php
+	$this->view('_submenu')
+	     ->display();
+?>
 
 <script type="text/javascript">
-function submitbutton(pressbutton) 
+function submitbutton(pressbutton)
 {
 	var form = document.adminForm;
 
@@ -93,7 +81,7 @@ function submitbutton(pressbutton)
 		</fieldset>
 		<fieldset>
 			<legend><span>New Transaction</span></legend>
-		
+
 				<table class="adminform">
 			 <tbody>
 			  <tr>
@@ -142,7 +130,7 @@ function submitbutton(pressbutton)
 		{
 ?>
 				<tr>
-					<td><?php echo JHTML::_('date',$item->created, $dateTimeFormat, $tz); ?></td>
+					<td><?php echo JHTML::_('date',$item->created, JText::_('DATE_FORMAT_HZ1') . ' ' . JText::_('TIME_FORMAT_HZ1')); ?></td>
 					<td><?php echo $item->description; ?></td>
 					<td><?php echo $item->category; ?></td>
 					<td><?php echo $item->type; ?></td>
@@ -169,7 +157,7 @@ function submitbutton(pressbutton)
 		</table>
 	</div>
 	<div class="clr"></div>
-	
+
 	<input type="hidden" name="id" value="<?php echo $this->row->id; ?>" />
 	<input type="hidden" name="option" value="<?php echo $this->option; ?>" />
 	<input type="hidden" name="controller" value="<?php echo $this->controller; ?>" />
