@@ -12,13 +12,13 @@
 // no direct access
 defined( '_JEXEC' ) or die( 'Restricted access' );
 
-$config =& JFactory::getConfig();
+$config = JFactory::getConfig();
 
 $this->template = 'hubbasic2012';
 
-$browser = new Hubzero_Browser();
-$b = $browser->getBrowser();
-$v = $browser->getBrowserMajorVersion();
+$browser = new \Hubzero\Browser\Detector();
+$b = $browser->name();
+$v = $browser->major();
 
 $this->setTitle($config->getValue('config.sitename') . ' - ' . JText::_('Down for maintenance'));
 ?>
